@@ -1,14 +1,16 @@
 #' @title Scale Bar
 #' @description Plot a scale bar. 
 #' @name barscale
-#' @param size size of the scale bar in kilometers. If size is not set, an 
-#' automatic size is used (1/10 of the map width).
+#' @param size size of the scale bar in units (default to km). If size is not 
+#' set, an automatic size is used (1/10 of the map width).
 #' @param lwd width of the scale bar.
 #' @param cex cex of the text.
 #' @param pos position of the legend, default to "bottomright". 
 #' "bottomright" or a vector of two coordinates (c(x, y)) are possible.
 #' @param style style of the legend, either "pretty" or "oldschool". The 
 #' "oldschool" style only uses the "size" parameter.   
+#' @param unit units used for the scale bar. Can be "mi" for miles, 
+#' "m" for meters, or "km" for kilometers (default)
 #' @note This scale bar is not accurate on unprojected (long/lat) maps.
 #' @export
 #' @seealso \link{layoutLayer}
@@ -18,7 +20,8 @@
 #' plot(st_geometry(mtq), col = "grey60", border = "grey20")
 #' barscale(size = 5)
 #' barscale(size = 5, lwd = 2, cex = .9, pos = c(714000, 1596000))
-barscale <- function(size, lwd = 1.5, cex = 0.6, pos = "bottomright", style="pretty"){
+barscale <- function(size, lwd = 1.5, cex = 0.6, 
+                     pos = "bottomright", style = "pretty", unit = "km"){
   # size = 10
   mapExtent <- par()$usr
   x <- mapExtent[1:2]
@@ -28,14 +31,17 @@ barscale <- function(size, lwd = 1.5, cex = 0.6, pos = "bottomright", style="pre
   # default scale
   if(missing(size) || is.null(size)){
     size <- diff(x)/10
-    size <- signif(size, digits = 0)
+    size <- unit_conversion(size = size, unit_in = "m", unit_out = unit)
+    size_text <- signif(size, digits = 0)
+    size <- unit_conversion(size = size_text, unit_in = unit, unit_out = "m")
   }else{
-    # km to m 
-    size <- size * 1000
+    # convert distance into meters based on dist_unit
+    size_text <- as.character(size)
+    size <- unit_conversion(size, unit_in = unit, unit_out = "m")
   }
   
   # label
-  labelscale <- paste(size / 1000, "km", sep =" ")
+  labelscale <- paste(size_text, unit, sep =" ")
   
   # xy pos
   xscale <- x[2] - inset * 0.5 - size
@@ -77,6 +83,28 @@ barscale <- function(size, lwd = 1.5, cex = 0.6, pos = "bottomright", style="pre
          })
 }
 
-
-
-
+#' Convert units
+#' @param size a size
+#' @param unit_in input unit
+#' @param unit_out output unit
+#' @noRd
+unit_conversion <- function(size, unit_in, unit_out){
+  # uncomment comments if the function is eventually exported
+  
+  # if(!unit_in %in% c('km','m','mi')) stop("unit must be 'km', 'm', or 'mi'")
+  if(!unit_out %in% c('km','m','mi')) stop("unit must be 'km', 'm', or 'mi'")
+  
+  if(unit_out == "m"){
+    if(unit_in == "km") size <- size * 1000
+    if(unit_in == "mi") size <- size * 1609.344
+  }
+  if(unit_out == "km"){
+    if(unit_in == "m") size <- size / 1000
+    # if(unit_in == "mi") size <- size * 1.609344
+  }
+  if(unit_out == "mi"){
+    if(unit_in == "m") size <- size / 1609.344
+    # if(unit_in == "km") size <- size / 1.609344
+  }
+  return(size)
+}
